@@ -6,11 +6,10 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef CALENDARVIEWS_JOURNALVIEW_H
-#define CALENDARVIEWS_JOURNALVIEW_H
+#pragma once
 
 #include "eventview.h"
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/IncidenceChanger>
 #include <KCalendarCore/Journal>
 
 class QScrollArea;
@@ -37,10 +36,10 @@ public:
     Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() const override;
     Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() const override
     {
-        return KCalendarCore::DateList();
+        return {};
     }
 
-    void appendJournal(const Akonadi::Item &journal, const QDate &dt);
+    void appendJournal(const Akonadi::Item &journal, QDate dt);
 
     /** documentation in baseview.h */
     void getHighlightMode(bool &highlightEvents, bool &highlightTodos, bool &highlightJournals);
@@ -81,4 +80,3 @@ private:
 };
 }
 
-#endif
