@@ -8,7 +8,7 @@
 
 #include "eventviews_export.h"
 
-#include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/ETMCalendar>
 #include <Akonadi/Item>
 #include <KCalendarCore/Incidence>
 
@@ -223,12 +223,12 @@ public:
     /**
       Returns the background color of the item.
     */
-    virtual Q_REQUIRED_RESULT QColor bgColor() const = 0;
+    Q_REQUIRED_RESULT virtual QColor bgColor() const = 0;
 
     /**
       Returns the frame color of the item.
     */
-    virtual Q_REQUIRED_RESULT QColor frameColor() const = 0;
+    Q_REQUIRED_RESULT virtual QColor frameColor() const = 0;
 
     /**
       Returns a list of pixmaps to draw next to the items.
