@@ -18,8 +18,8 @@
 #include <KGantt/KGanttItemDelegate>
 #include <KGantt/KGanttStyleOptionGanttItem>
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
 
@@ -214,7 +214,7 @@ TimelineView::TimelineView(const EventViews::PrefsPtr &preferences, QWidget *par
 
 TimelineView::TimelineView(QWidget *parent)
     : EventView(parent)
-    , d(new Private(this))
+    , d(new TimelineViewPrivate(this))
 {
     auto vbox = new QVBoxLayout(this);
     auto splitter = new QSplitter(Qt::Horizontal, this);
@@ -254,17 +254,16 @@ TimelineView::TimelineView(QWidget *parent)
 
     vbox->addWidget(splitter);
 
-    connect(model, &QStandardItemModel::itemChanged, d, &Private::itemChanged);
+    connect(model, &QStandardItemModel::itemChanged, d.get(), &TimelineViewPrivate::itemChanged);
 
-    connect(d->mGantt, &KGantt::GraphicsView::activated, d, &Private::itemSelected);
+    connect(d->mGantt, &KGantt::GraphicsView::activated, d.get(), &TimelineViewPrivate::itemSelected);
     d->mGantt->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(d->mGantt, &QWidget::customContextMenuRequested, d, &Private::contextMenuRequested);
+    connect(d->mGantt, &QWidget::customContextMenuRequested, d.get(), &TimelineViewPrivate::contextMenuRequested);
 }
 
 TimelineView::~TimelineView()
 {
     delete d->mRowController;
-    delete d;
 }
 
 Akonadi::Item::List TimelineView::selectedIncidences() const
@@ -274,7 +273,7 @@ Akonadi::Item::List TimelineView::selectedIncidences() const
 
 KCalendarCore::DateList TimelineView::selectedIncidenceDates() const
 {
-    return KCalendarCore::DateList();
+    return {};
 }
 
 int TimelineView::currentDateCount() const
@@ -299,11 +298,9 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     grid->setStartDateTime(QDateTime(start.startOfDay()));
     d->mLeftView->clear();
     uint index = 0;
-    // item for every calendar
-    TimelineItem *item = nullptr;
     Akonadi::ETMCalendar::Ptr calres = calendar();
     if (!calres) {
-        item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
+        auto item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
         d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << i18n("Calendar")));
         d->mCalendarItemMap.insert(-1, item);
     } else {
@@ -312,7 +309,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
 
         for (const Akonadi::Collection &collection : collections) {
             if (collection.contentMimeTypes().contains(Event::eventMimeType())) {
-                item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
+                auto item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
                 d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << CalendarSupport::displayName(calendar().data(), collection)));
                 const QColor resourceColor = EventViews::resourceColor(collection, preferences());
                 if (resourceColor.isValid()) {
