@@ -189,7 +189,10 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     if (!mSidebarView) {
         mQuickSearch = new TodoViewQuickSearch(calendar(), this);
         mQuickSearch->setVisible(prefs->enableTodoQuickSearch());
-        connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, mProxyModel, qOverload<const QString &>(&QSortFilterProxyModel::setFilterRegExp));
+        connect(mQuickSearch,
+                &TodoViewQuickSearch::searchTextChanged,
+                mProxyModel,
+                qOverload<const QString &>(&QSortFilterProxyModel::setFilterRegularExpression));
         connect(mQuickSearch, &TodoViewQuickSearch::searchTextChanged, this, &TodoView::restoreViewState);
         connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, mProxyModel, &TodoViewSortFilterProxyModel::setCategoryFilter);
         connect(mQuickSearch, &TodoViewQuickSearch::filterCategoryChanged, this, &TodoView::restoreViewState);
@@ -240,7 +243,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mQuickAdd = new TodoViewQuickAddLine(this);
     mQuickAdd->setClearButtonEnabled(true);
     mQuickAdd->setVisible(preferences()->enableQuickTodo());
-    connect(mQuickAdd, SIGNAL(returnPressed(Qt::KeyboardModifiers)), this, SLOT(addQuickTodo(Qt::KeyboardModifiers)));
+    connect(mQuickAdd, &TodoViewQuickAddLine::returnPressed, this, &TodoView::addQuickTodo);
 
     mFullViewButton = nullptr;
     if (!mSidebarView) {
@@ -260,7 +263,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                         "flat list instead of a hierarchical tree; the parental "
                                         "relationships are removed in the display."));
 
-    connect(mFlatViewButton, SIGNAL(toggled(bool)), SLOT(setFlatView(bool)));
+    connect(mFlatViewButton, &QToolButton::toggled, this, [=](bool flatView) {setFlatView(flatView, true);});
     if (mFullViewButton) {
         connect(mFullViewButton, &QToolButton::toggled, this, &TodoView::setFullView);
     }
@@ -349,7 +352,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     a = mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("appointment-new")),
                                   i18nc("@action:inmenu", "Create Event from To-do"),
                                   this,
-                                  SLOT(createEvent()));
+                                  qOverload<>(&TodoView::createEvent));
     a->setObjectName(QStringLiteral("createevent"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
@@ -357,7 +360,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     a = mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")),
                                   i18nc("@action:inmenu", "Create Note for To-do"),
                                   this,
-                                  SLOT(createNote()));
+                                  qOverload<>(&TodoView::createNote));
     a->setObjectName(QStringLiteral("createnote"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
@@ -381,6 +384,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mMovePopupMenu->setTitle(i18nc("@title:menu", "&Move To"));
 
     connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::setNewDate);
+    connect(mView->startPopupMenu(), &CalendarSupport::KDatePickerPopup::dateChanged, this, &TodoView::setStartDate);
 
     connect(mMovePopupMenu, &CalendarSupport::KDatePickerPopup::dateChanged, mItemPopupMenu, &QMenu::hide);
 
@@ -471,7 +475,7 @@ DateList TodoView::selectedIncidenceDates() const
     // return something about the selected todo here, because it has got
     // a couple of dates (creation, due date, completion date), and the
     // caller could not figure out what he gets. So just return an empty list.
-    return DateList();
+    return {};
 }
 
 void TodoView::saveLayout(KConfig *config, const QString &group) const
@@ -705,6 +709,8 @@ void TodoView::contextMenu(QPoint pos)
             mPercentageCompletedPopupMenu->popup(mView->viewport()->mapToGlobal(pos));
             break;
         case TodoModel::StartDateColumn:
+            mView->startPopupMenu()->popup(mView->viewport()->mapToGlobal(pos));
+            break;
         case TodoModel::DueDateColumn:
             mMovePopupMenu->popup(mView->viewport()->mapToGlobal(pos));
             break;
@@ -908,6 +914,9 @@ void TodoView::setNewDate(QDate date)
             dt.setTime(todo->dtDue().time());
         }
 
+        if (todo->hasStartDate() && dt < todo->dtStart()) {
+            todo->setDtStart(dt);
+        }
         todo->setDtDue(dt);
 
         changer()->modifyIncidence(todoItem, oldTodo, this);
@@ -916,6 +925,37 @@ void TodoView::setNewDate(QDate date)
     }
 }
 
+void TodoView::setStartDate(QDate date)
+{
+    QModelIndexList selection = mView->selectionModel()->selectedRows();
+    if (selection.size() != 1) {
+        return;
+    }
+
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
+    Q_ASSERT(todo);
+
+    if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
+        KCalendarCore::Todo::Ptr oldTodo(todo->clone());
+        QDateTime dt(date.startOfDay());
+
+        if (!todo->allDay()) {
+            dt.setTime(todo->dtStart().time());
+        }
+
+        if (todo->hasDueDate() && dt > todo->dtDue()) {
+            todo->setDtDue(dt);
+        }
+        todo->setDtStart(dt);
+
+        changer()->modifyIncidence(todoItem, oldTodo, this);
+    } else {
+        qCDebug(CALENDARVIEW_LOG) << "Item is readOnly";
+    }
+}
+
+
 void TodoView::setNewPercentage(QAction *action)
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
